package com.zcloud.modules.kangzai.controller;

import com.zcloud.common.annotation.SysLog;
import com.zcloud.common.utils.PageUtils;
import com.zcloud.common.utils.R;
import com.zcloud.common.utils.Tools;
import com.zcloud.modules.kangzai.entity.BusRiverSectionsEntity;
import com.zcloud.modules.kangzai.service.BusRiverSectionsService;
import com.zcloud.modules.sys.controller.AbstractController;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import java.util.Map;

/**
 * @Author fangjiakai
 * @Desc 河流县区段信息表(BusRiverSections)表控制层
 * @Date 2025-06-09 09:44:25
 */
@Api(tags = "河流县区段信息表")
@RestController
@RequestMapping("busRiverSections")
public class BusRiverSectionsController extends AbstractController {

    @Autowired
    private BusRiverSectionsService busRiverSectionsService;

    @ApiOperation("河流县区段信息表-新增数据")
    @SysLog("河流县区段信息表-新增数据")
    @PostMapping("/save")
    public R insert(@RequestBody BusRiverSectionsEntity param) {
        busRiverSectionsService.save(param);

        return R.ok();
    }

    @ApiOperation("河流县区段信息表-编辑数据")
    @SysLog("河流县区段信息表-编辑数据")
    @PostMapping("/update")
    public R update(@RequestBody BusRiverSectionsEntity param) {
        busRiverSectionsService.updateById(param);

        return R.ok();
    }


    @ApiOperation("河流县区段信息表-删除数据")
    @SysLog("河流县区段信息表-删除数据")
    @PostMapping("/delete")
    public R delete(@RequestBody BusRiverSectionsEntity param) {
        busRiverSectionsService.delete(param.getRiverSectionsId(), getUserId());
        return R.ok();
    }

    @ApiOperation("河流县区段信息表-分页查询")
    @SysLog("河流县区段信息表-分页查询")
    @PostMapping("/listPage")
    public R listPage(@RequestBody Map<String, Object> params) {
        PageUtils page = busRiverSectionsService.listPage(params);

        return R.ok().put("page", page);
    }


    @ApiOperation("河流县区段信息表-根据ID查详情")
    @SysLog("河流县区段信息表-根据ID查详情")
    @PostMapping("/info")
    public R info(@RequestBody BusRiverSectionsEntity param) {
        BusRiverSectionsEntity busRiverSections = busRiverSectionsService.getById(param.getRiverSectionsId());
        return R.ok().put("busRiverSections", busRiverSections);
    }

    @PostMapping("/list")
    public R list() {
        return R.ok().put("list", busRiverSectionsService.queryByFlexibleParams("is_delete", "0"));
    }
}
